# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""SWIG wrapper for the CGAL dD Spatial Searching package provided under the GPL-3.0+ license"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _CGAL_Spatial_searching
else:
    import _CGAL_Spatial_searching

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import CGAL.CGAL_Kernel
class Point_with_transformed_distance_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Point_with_transformed_distance_2_swiginit(self, _CGAL_Spatial_searching.new_Point_with_transformed_distance_2(*args))
    first = property(_CGAL_Spatial_searching.Point_with_transformed_distance_2_first_get, _CGAL_Spatial_searching.Point_with_transformed_distance_2_first_set)
    second = property(_CGAL_Spatial_searching.Point_with_transformed_distance_2_second_get, _CGAL_Spatial_searching.Point_with_transformed_distance_2_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Point_with_transformed_distance_2

# Register Point_with_transformed_distance_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Point_with_transformed_distance_2_swigregister(Point_with_transformed_distance_2)

class Point_with_transformed_distance_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Point_with_transformed_distance_3_swiginit(self, _CGAL_Spatial_searching.new_Point_with_transformed_distance_3(*args))
    first = property(_CGAL_Spatial_searching.Point_with_transformed_distance_3_first_get, _CGAL_Spatial_searching.Point_with_transformed_distance_3_first_set)
    second = property(_CGAL_Spatial_searching.Point_with_transformed_distance_3_second_get, _CGAL_Spatial_searching.Point_with_transformed_distance_3_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Point_with_transformed_distance_3

# Register Point_with_transformed_distance_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Point_with_transformed_distance_3_swigregister(Point_with_transformed_distance_3)

class Fuzzy_sphere_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Fuzzy_sphere_2_swiginit(self, _CGAL_Spatial_searching.new_Fuzzy_sphere_2(*args))

    def contains(self, c):
        return _CGAL_Spatial_searching.Fuzzy_sphere_2_contains(self, c)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Fuzzy_sphere_2_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Fuzzy_sphere_2

# Register Fuzzy_sphere_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Fuzzy_sphere_2_swigregister(Fuzzy_sphere_2)

class Fuzzy_iso_box_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Fuzzy_iso_box_2_swiginit(self, _CGAL_Spatial_searching.new_Fuzzy_iso_box_2(*args))

    def contains(self, c):
        return _CGAL_Spatial_searching.Fuzzy_iso_box_2_contains(self, c)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Fuzzy_iso_box_2_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Fuzzy_iso_box_2

# Register Fuzzy_iso_box_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Fuzzy_iso_box_2_swigregister(Fuzzy_iso_box_2)

class Fuzzy_sphere_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Fuzzy_sphere_3_swiginit(self, _CGAL_Spatial_searching.new_Fuzzy_sphere_3(*args))

    def contains(self, c):
        return _CGAL_Spatial_searching.Fuzzy_sphere_3_contains(self, c)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Fuzzy_sphere_3_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Fuzzy_sphere_3

# Register Fuzzy_sphere_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Fuzzy_sphere_3_swigregister(Fuzzy_sphere_3)

class Fuzzy_iso_box_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Fuzzy_iso_box_3_swiginit(self, _CGAL_Spatial_searching.new_Fuzzy_iso_box_3(*args))

    def contains(self, c):
        return _CGAL_Spatial_searching.Fuzzy_iso_box_3_contains(self, c)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Fuzzy_iso_box_3_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Fuzzy_iso_box_3

# Register Fuzzy_iso_box_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Fuzzy_iso_box_3_swigregister(Fuzzy_iso_box_3)

class Orthogonal_incremental_neighbor_search_tree_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_tree_2(*args))

    def insert(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_tree_2

# Register Orthogonal_incremental_neighbor_search_tree_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_swigregister(Orthogonal_incremental_neighbor_search_tree_2)

class Orthogonal_incremental_neighbor_search_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_2_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_2(*args))

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_2_iterator(self)

    def value(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_2_value(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_2

# Register Orthogonal_incremental_neighbor_search_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_2_swigregister(Orthogonal_incremental_neighbor_search_2)

class Orthogonal_incremental_neighbor_search_tree_iterator_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_tree_iterator_2())

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_tree_iterator_2

# Register Orthogonal_incremental_neighbor_search_tree_iterator_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2_swigregister(Orthogonal_incremental_neighbor_search_tree_iterator_2)

class Orthogonal_incremental_neighbor_search_iterator_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_iterator_2())

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_iterator_2

# Register Orthogonal_incremental_neighbor_search_iterator_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2_swigregister(Orthogonal_incremental_neighbor_search_iterator_2)

class Incremental_neighbor_search_tree_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_swiginit(self, _CGAL_Spatial_searching.new_Incremental_neighbor_search_tree_2(*args))

    def insert(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_tree_2

# Register Incremental_neighbor_search_tree_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_swigregister(Incremental_neighbor_search_tree_2)

class Incremental_neighbor_search_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Incremental_neighbor_search_2_swiginit(self, _CGAL_Spatial_searching.new_Incremental_neighbor_search_2(*args))

    def iterator(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_2_iterator(self)

    def value(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_2_value(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_2

# Register Incremental_neighbor_search_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Incremental_neighbor_search_2_swigregister(Incremental_neighbor_search_2)

class Incremental_neighbor_search_tree_iterator_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2_swiginit(self, _CGAL_Spatial_searching.new_Incremental_neighbor_search_tree_iterator_2())

    def __iter__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_tree_iterator_2

# Register Incremental_neighbor_search_tree_iterator_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2_swigregister(Incremental_neighbor_search_tree_iterator_2)

class Incremental_neighbor_search_iterator_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2_swiginit(self, _CGAL_Spatial_searching.new_Incremental_neighbor_search_iterator_2())

    def __iter__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_iterator_2

# Register Incremental_neighbor_search_iterator_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2_swigregister(Incremental_neighbor_search_iterator_2)

class K_neighbor_search_tree_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.K_neighbor_search_tree_2_swiginit(self, _CGAL_Spatial_searching.new_K_neighbor_search_tree_2(*args))

    def insert(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_tree_2

# Register K_neighbor_search_tree_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.K_neighbor_search_tree_2_swigregister(K_neighbor_search_tree_2)

class K_neighbor_search_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.K_neighbor_search_2_swiginit(self, _CGAL_Spatial_searching.new_K_neighbor_search_2(*args))

    def iterator(self):
        return _CGAL_Spatial_searching.K_neighbor_search_2_iterator(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_2

# Register K_neighbor_search_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.K_neighbor_search_2_swigregister(K_neighbor_search_2)

class K_neighbor_search_tree_iterator_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2_swiginit(self, _CGAL_Spatial_searching.new_K_neighbor_search_tree_iterator_2())

    def __iter__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_tree_iterator_2

# Register K_neighbor_search_tree_iterator_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2_swigregister(K_neighbor_search_tree_iterator_2)

class K_neighbor_search_iterator_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.K_neighbor_search_iterator_2_swiginit(self, _CGAL_Spatial_searching.new_K_neighbor_search_iterator_2())

    def __iter__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_iterator_2

# Register K_neighbor_search_iterator_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.K_neighbor_search_iterator_2_swigregister(K_neighbor_search_iterator_2)

class Orthogonal_k_neighbor_search_tree_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_tree_2(*args))

    def insert(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_tree_2

# Register Orthogonal_k_neighbor_search_tree_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_swigregister(Orthogonal_k_neighbor_search_tree_2)

class Orthogonal_k_neighbor_search_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_2_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_2(*args))

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_2_iterator(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_2

# Register Orthogonal_k_neighbor_search_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_k_neighbor_search_2_swigregister(Orthogonal_k_neighbor_search_2)

class Orthogonal_k_neighbor_search_tree_iterator_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_tree_iterator_2())

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_tree_iterator_2

# Register Orthogonal_k_neighbor_search_tree_iterator_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2_swigregister(Orthogonal_k_neighbor_search_tree_iterator_2)

class Orthogonal_k_neighbor_search_iterator_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_iterator_2())

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_iterator_2

# Register Orthogonal_k_neighbor_search_iterator_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2_swigregister(Orthogonal_k_neighbor_search_iterator_2)

class Orthogonal_incremental_neighbor_search_tree_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_tree_3(*args))

    def insert(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_tree_3

# Register Orthogonal_incremental_neighbor_search_tree_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_swigregister(Orthogonal_incremental_neighbor_search_tree_3)

class Orthogonal_incremental_neighbor_search_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_3_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_3(*args))

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_3_iterator(self)

    def value(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_3_value(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_3

# Register Orthogonal_incremental_neighbor_search_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_3_swigregister(Orthogonal_incremental_neighbor_search_3)

class Orthogonal_incremental_neighbor_search_tree_iterator_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_tree_iterator_3())

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_tree_iterator_3

# Register Orthogonal_incremental_neighbor_search_tree_iterator_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3_swigregister(Orthogonal_incremental_neighbor_search_tree_iterator_3)

class Orthogonal_incremental_neighbor_search_iterator_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_iterator_3())

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_iterator_3

# Register Orthogonal_incremental_neighbor_search_iterator_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3_swigregister(Orthogonal_incremental_neighbor_search_iterator_3)

class Incremental_neighbor_search_tree_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_swiginit(self, _CGAL_Spatial_searching.new_Incremental_neighbor_search_tree_3(*args))

    def insert(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_tree_3

# Register Incremental_neighbor_search_tree_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_swigregister(Incremental_neighbor_search_tree_3)

class Incremental_neighbor_search_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Incremental_neighbor_search_3_swiginit(self, _CGAL_Spatial_searching.new_Incremental_neighbor_search_3(*args))

    def iterator(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_3_iterator(self)

    def value(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_3_value(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_3

# Register Incremental_neighbor_search_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Incremental_neighbor_search_3_swigregister(Incremental_neighbor_search_3)

class Incremental_neighbor_search_tree_iterator_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3_swiginit(self, _CGAL_Spatial_searching.new_Incremental_neighbor_search_tree_iterator_3())

    def __iter__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_tree_iterator_3

# Register Incremental_neighbor_search_tree_iterator_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3_swigregister(Incremental_neighbor_search_tree_iterator_3)

class Incremental_neighbor_search_iterator_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3_swiginit(self, _CGAL_Spatial_searching.new_Incremental_neighbor_search_iterator_3())

    def __iter__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_iterator_3

# Register Incremental_neighbor_search_iterator_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3_swigregister(Incremental_neighbor_search_iterator_3)

class K_neighbor_search_tree_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.K_neighbor_search_tree_3_swiginit(self, _CGAL_Spatial_searching.new_K_neighbor_search_tree_3(*args))

    def insert(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_tree_3

# Register K_neighbor_search_tree_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.K_neighbor_search_tree_3_swigregister(K_neighbor_search_tree_3)

class K_neighbor_search_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.K_neighbor_search_3_swiginit(self, _CGAL_Spatial_searching.new_K_neighbor_search_3(*args))

    def iterator(self):
        return _CGAL_Spatial_searching.K_neighbor_search_3_iterator(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_3

# Register K_neighbor_search_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.K_neighbor_search_3_swigregister(K_neighbor_search_3)

class K_neighbor_search_tree_iterator_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3_swiginit(self, _CGAL_Spatial_searching.new_K_neighbor_search_tree_iterator_3())

    def __iter__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_tree_iterator_3

# Register K_neighbor_search_tree_iterator_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3_swigregister(K_neighbor_search_tree_iterator_3)

class K_neighbor_search_iterator_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.K_neighbor_search_iterator_3_swiginit(self, _CGAL_Spatial_searching.new_K_neighbor_search_iterator_3())

    def __iter__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_iterator_3

# Register K_neighbor_search_iterator_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.K_neighbor_search_iterator_3_swigregister(K_neighbor_search_iterator_3)

class Orthogonal_k_neighbor_search_tree_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_tree_3(*args))

    def insert(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_tree_3

# Register Orthogonal_k_neighbor_search_tree_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_swigregister(Orthogonal_k_neighbor_search_tree_3)

class Orthogonal_k_neighbor_search_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_3_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_3(*args))

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_3_iterator(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_3

# Register Orthogonal_k_neighbor_search_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_k_neighbor_search_3_swigregister(Orthogonal_k_neighbor_search_3)

class Orthogonal_k_neighbor_search_tree_iterator_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_tree_iterator_3())

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_tree_iterator_3

# Register Orthogonal_k_neighbor_search_tree_iterator_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3_swigregister(Orthogonal_k_neighbor_search_tree_iterator_3)

class Orthogonal_k_neighbor_search_iterator_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_iterator_3())

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_iterator_3

# Register Orthogonal_k_neighbor_search_iterator_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3_swigregister(Orthogonal_k_neighbor_search_iterator_3)






# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""SWIG wrapper for the CGAL Polygon Mesh Processing package provided under the GPL-3.0+ license"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _CGAL_Polygon_mesh_processing
else:
    import _CGAL_Polygon_mesh_processing

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import CGAL.CGAL_Kernel
import CGAL.CGAL_Polyhedron_3
class Polygon_mesh_slicer(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, poly):
        _CGAL_Polygon_mesh_processing.Polygon_mesh_slicer_swiginit(self, _CGAL_Polygon_mesh_processing.new_Polygon_mesh_slicer(poly))

    def slice(self, plane, out):
        return _CGAL_Polygon_mesh_processing.Polygon_mesh_slicer_slice(self, plane, out)
    __swig_destroy__ = _CGAL_Polygon_mesh_processing.delete_Polygon_mesh_slicer

# Register Polygon_mesh_slicer in _CGAL_Polygon_mesh_processing:
_CGAL_Polygon_mesh_processing.Polygon_mesh_slicer_swigregister(Polygon_mesh_slicer)

class Side_of_triangle_mesh(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, poly):
        _CGAL_Polygon_mesh_processing.Side_of_triangle_mesh_swiginit(self, _CGAL_Polygon_mesh_processing.new_Side_of_triangle_mesh(poly))

    def bounded_side(self, p):
        return _CGAL_Polygon_mesh_processing.Side_of_triangle_mesh_bounded_side(self, p)
    __swig_destroy__ = _CGAL_Polygon_mesh_processing.delete_Side_of_triangle_mesh

# Register Side_of_triangle_mesh in _CGAL_Polygon_mesh_processing:
_CGAL_Polygon_mesh_processing.Side_of_triangle_mesh_swigregister(Side_of_triangle_mesh)

class Integer_triple(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    first = property(_CGAL_Polygon_mesh_processing.Integer_triple_first_get, _CGAL_Polygon_mesh_processing.Integer_triple_first_set)
    second = property(_CGAL_Polygon_mesh_processing.Integer_triple_second_get, _CGAL_Polygon_mesh_processing.Integer_triple_second_set)
    third = property(_CGAL_Polygon_mesh_processing.Integer_triple_third_get, _CGAL_Polygon_mesh_processing.Integer_triple_third_set)

    def __init__(self, *args):
        _CGAL_Polygon_mesh_processing.Integer_triple_swiginit(self, _CGAL_Polygon_mesh_processing.new_Integer_triple(*args))

    def deepcopy(self, *args):
        return _CGAL_Polygon_mesh_processing.Integer_triple_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Polygon_mesh_processing.delete_Integer_triple

# Register Integer_triple in _CGAL_Polygon_mesh_processing:
_CGAL_Polygon_mesh_processing.Integer_triple_swigregister(Integer_triple)

class Facet_pair(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Polygon_mesh_processing.Facet_pair_swiginit(self, _CGAL_Polygon_mesh_processing.new_Facet_pair(*args))
    first = property(_CGAL_Polygon_mesh_processing.Facet_pair_first_get, _CGAL_Polygon_mesh_processing.Facet_pair_first_set)
    second = property(_CGAL_Polygon_mesh_processing.Facet_pair_second_get, _CGAL_Polygon_mesh_processing.Facet_pair_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_Polygon_mesh_processing.delete_Facet_pair

# Register Facet_pair in _CGAL_Polygon_mesh_processing:
_CGAL_Polygon_mesh_processing.Facet_pair_swigregister(Facet_pair)

class Halfedge_pair(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Polygon_mesh_processing.Halfedge_pair_swiginit(self, _CGAL_Polygon_mesh_processing.new_Halfedge_pair(*args))
    first = property(_CGAL_Polygon_mesh_processing.Halfedge_pair_first_get, _CGAL_Polygon_mesh_processing.Halfedge_pair_first_set)
    second = property(_CGAL_Polygon_mesh_processing.Halfedge_pair_second_get, _CGAL_Polygon_mesh_processing.Halfedge_pair_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_Polygon_mesh_processing.delete_Halfedge_pair

# Register Halfedge_pair in _CGAL_Polygon_mesh_processing:
_CGAL_Polygon_mesh_processing.Halfedge_pair_swigregister(Halfedge_pair)

class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _CGAL_Polygon_mesh_processing.delete_SwigPyIterator

    def value(self):
        return _CGAL_Polygon_mesh_processing.SwigPyIterator_value(self)

    def incr(self, n=1):
        return _CGAL_Polygon_mesh_processing.SwigPyIterator_incr(self, n)

    def decr(self, n=1):
        return _CGAL_Polygon_mesh_processing.SwigPyIterator_decr(self, n)

    def distance(self, x):
        return _CGAL_Polygon_mesh_processing.SwigPyIterator_distance(self, x)

    def equal(self, x):
        return _CGAL_Polygon_mesh_processing.SwigPyIterator_equal(self, x)

    def copy(self):
        return _CGAL_Polygon_mesh_processing.SwigPyIterator_copy(self)

    def next(self):
        return _CGAL_Polygon_mesh_processing.SwigPyIterator_next(self)

    def __next__(self):
        return _CGAL_Polygon_mesh_processing.SwigPyIterator___next__(self)

    def previous(self):
        return _CGAL_Polygon_mesh_processing.SwigPyIterator_previous(self)

    def advance(self, n):
        return _CGAL_Polygon_mesh_processing.SwigPyIterator_advance(self, n)

    def __eq__(self, x):
        return _CGAL_Polygon_mesh_processing.SwigPyIterator___eq__(self, x)

    def __ne__(self, x):
        return _CGAL_Polygon_mesh_processing.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n):
        return _CGAL_Polygon_mesh_processing.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n):
        return _CGAL_Polygon_mesh_processing.SwigPyIterator___isub__(self, n)

    def __add__(self, n):
        return _CGAL_Polygon_mesh_processing.SwigPyIterator___add__(self, n)

    def __sub__(self, *args):
        return _CGAL_Polygon_mesh_processing.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _CGAL_Polygon_mesh_processing:
_CGAL_Polygon_mesh_processing.SwigPyIterator_swigregister(SwigPyIterator)

class Point_3_Vector(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector___nonzero__(self)

    def __bool__(self):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector___bool__(self)

    def __len__(self):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector___len__(self)

    def __getslice__(self, i, j):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector___delitem__(self, *args)

    def __getitem__(self, *args):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector___getitem__(self, *args)

    def __setitem__(self, *args):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector___setitem__(self, *args)

    def pop(self):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_pop(self)

    def append(self, x):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_append(self, x)

    def empty(self):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_empty(self)

    def size(self):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_size(self)

    def swap(self, v):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_swap(self, v)

    def begin(self):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_begin(self)

    def end(self):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_end(self)

    def rbegin(self):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_rbegin(self)

    def rend(self):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_rend(self)

    def clear(self):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_clear(self)

    def get_allocator(self):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_get_allocator(self)

    def pop_back(self):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_pop_back(self)

    def erase(self, *args):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_erase(self, *args)

    def __init__(self, *args):
        _CGAL_Polygon_mesh_processing.Point_3_Vector_swiginit(self, _CGAL_Polygon_mesh_processing.new_Point_3_Vector(*args))

    def push_back(self, x):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_push_back(self, x)

    def front(self):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_front(self)

    def back(self):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_back(self)

    def assign(self, n, x):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_assign(self, n, x)

    def resize(self, *args):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_resize(self, *args)

    def insert(self, *args):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_insert(self, *args)

    def reserve(self, n):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_reserve(self, n)

    def capacity(self):
        return _CGAL_Polygon_mesh_processing.Point_3_Vector_capacity(self)
    __swig_destroy__ = _CGAL_Polygon_mesh_processing.delete_Point_3_Vector

# Register Point_3_Vector in _CGAL_Polygon_mesh_processing:
_CGAL_Polygon_mesh_processing.Point_3_Vector_swigregister(Point_3_Vector)

class Int_Vector(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _CGAL_Polygon_mesh_processing.Int_Vector_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _CGAL_Polygon_mesh_processing.Int_Vector___nonzero__(self)

    def __bool__(self):
        return _CGAL_Polygon_mesh_processing.Int_Vector___bool__(self)

    def __len__(self):
        return _CGAL_Polygon_mesh_processing.Int_Vector___len__(self)

    def __getslice__(self, i, j):
        return _CGAL_Polygon_mesh_processing.Int_Vector___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _CGAL_Polygon_mesh_processing.Int_Vector___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _CGAL_Polygon_mesh_processing.Int_Vector___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _CGAL_Polygon_mesh_processing.Int_Vector___delitem__(self, *args)

    def __getitem__(self, *args):
        return _CGAL_Polygon_mesh_processing.Int_Vector___getitem__(self, *args)

    def __setitem__(self, *args):
        return _CGAL_Polygon_mesh_processing.Int_Vector___setitem__(self, *args)

    def pop(self):
        return _CGAL_Polygon_mesh_processing.Int_Vector_pop(self)

    def append(self, x):
        return _CGAL_Polygon_mesh_processing.Int_Vector_append(self, x)

    def empty(self):
        return _CGAL_Polygon_mesh_processing.Int_Vector_empty(self)

    def size(self):
        return _CGAL_Polygon_mesh_processing.Int_Vector_size(self)

    def swap(self, v):
        return _CGAL_Polygon_mesh_processing.Int_Vector_swap(self, v)

    def begin(self):
        return _CGAL_Polygon_mesh_processing.Int_Vector_begin(self)

    def end(self):
        return _CGAL_Polygon_mesh_processing.Int_Vector_end(self)

    def rbegin(self):
        return _CGAL_Polygon_mesh_processing.Int_Vector_rbegin(self)

    def rend(self):
        return _CGAL_Polygon_mesh_processing.Int_Vector_rend(self)

    def clear(self):
        return _CGAL_Polygon_mesh_processing.Int_Vector_clear(self)

    def get_allocator(self):
        return _CGAL_Polygon_mesh_processing.Int_Vector_get_allocator(self)

    def pop_back(self):
        return _CGAL_Polygon_mesh_processing.Int_Vector_pop_back(self)

    def erase(self, *args):
        return _CGAL_Polygon_mesh_processing.Int_Vector_erase(self, *args)

    def __init__(self, *args):
        _CGAL_Polygon_mesh_processing.Int_Vector_swiginit(self, _CGAL_Polygon_mesh_processing.new_Int_Vector(*args))

    def push_back(self, x):
        return _CGAL_Polygon_mesh_processing.Int_Vector_push_back(self, x)

    def front(self):
        return _CGAL_Polygon_mesh_processing.Int_Vector_front(self)

    def back(self):
        return _CGAL_Polygon_mesh_processing.Int_Vector_back(self)

    def assign(self, n, x):
        return _CGAL_Polygon_mesh_processing.Int_Vector_assign(self, n, x)

    def resize(self, *args):
        return _CGAL_Polygon_mesh_processing.Int_Vector_resize(self, *args)

    def insert(self, *args):
        return _CGAL_Polygon_mesh_processing.Int_Vector_insert(self, *args)

    def reserve(self, n):
        return _CGAL_Polygon_mesh_processing.Int_Vector_reserve(self, n)

    def capacity(self):
        return _CGAL_Polygon_mesh_processing.Int_Vector_capacity(self)
    __swig_destroy__ = _CGAL_Polygon_mesh_processing.delete_Int_Vector

# Register Int_Vector in _CGAL_Polygon_mesh_processing:
_CGAL_Polygon_mesh_processing.Int_Vector_swigregister(Int_Vector)

class Polygon_Vector(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector___nonzero__(self)

    def __bool__(self):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector___bool__(self)

    def __len__(self):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector___len__(self)

    def __getslice__(self, i, j):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector___delitem__(self, *args)

    def __getitem__(self, *args):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector___getitem__(self, *args)

    def __setitem__(self, *args):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector___setitem__(self, *args)

    def pop(self):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_pop(self)

    def append(self, x):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_append(self, x)

    def empty(self):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_empty(self)

    def size(self):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_size(self)

    def swap(self, v):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_swap(self, v)

    def begin(self):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_begin(self)

    def end(self):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_end(self)

    def rbegin(self):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_rbegin(self)

    def rend(self):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_rend(self)

    def clear(self):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_clear(self)

    def get_allocator(self):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_get_allocator(self)

    def pop_back(self):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_pop_back(self)

    def erase(self, *args):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_erase(self, *args)

    def __init__(self, *args):
        _CGAL_Polygon_mesh_processing.Polygon_Vector_swiginit(self, _CGAL_Polygon_mesh_processing.new_Polygon_Vector(*args))

    def push_back(self, x):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_push_back(self, x)

    def front(self):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_front(self)

    def back(self):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_back(self)

    def assign(self, n, x):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_assign(self, n, x)

    def resize(self, *args):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_resize(self, *args)

    def insert(self, *args):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_insert(self, *args)

    def reserve(self, n):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_reserve(self, n)

    def capacity(self):
        return _CGAL_Polygon_mesh_processing.Polygon_Vector_capacity(self)
    __swig_destroy__ = _CGAL_Polygon_mesh_processing.delete_Polygon_Vector

# Register Polygon_Vector in _CGAL_Polygon_mesh_processing:
_CGAL_Polygon_mesh_processing.Polygon_Vector_swigregister(Polygon_Vector)

class Polylines(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _CGAL_Polygon_mesh_processing.Polylines_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _CGAL_Polygon_mesh_processing.Polylines___nonzero__(self)

    def __bool__(self):
        return _CGAL_Polygon_mesh_processing.Polylines___bool__(self)

    def __len__(self):
        return _CGAL_Polygon_mesh_processing.Polylines___len__(self)

    def __getslice__(self, i, j):
        return _CGAL_Polygon_mesh_processing.Polylines___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _CGAL_Polygon_mesh_processing.Polylines___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _CGAL_Polygon_mesh_processing.Polylines___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _CGAL_Polygon_mesh_processing.Polylines___delitem__(self, *args)

    def __getitem__(self, *args):
        return _CGAL_Polygon_mesh_processing.Polylines___getitem__(self, *args)

    def __setitem__(self, *args):
        return _CGAL_Polygon_mesh_processing.Polylines___setitem__(self, *args)

    def pop(self):
        return _CGAL_Polygon_mesh_processing.Polylines_pop(self)

    def append(self, x):
        return _CGAL_Polygon_mesh_processing.Polylines_append(self, x)

    def empty(self):
        return _CGAL_Polygon_mesh_processing.Polylines_empty(self)

    def size(self):
        return _CGAL_Polygon_mesh_processing.Polylines_size(self)

    def swap(self, v):
        return _CGAL_Polygon_mesh_processing.Polylines_swap(self, v)

    def begin(self):
        return _CGAL_Polygon_mesh_processing.Polylines_begin(self)

    def end(self):
        return _CGAL_Polygon_mesh_processing.Polylines_end(self)

    def rbegin(self):
        return _CGAL_Polygon_mesh_processing.Polylines_rbegin(self)

    def rend(self):
        return _CGAL_Polygon_mesh_processing.Polylines_rend(self)

    def clear(self):
        return _CGAL_Polygon_mesh_processing.Polylines_clear(self)

    def get_allocator(self):
        return _CGAL_Polygon_mesh_processing.Polylines_get_allocator(self)

    def pop_back(self):
        return _CGAL_Polygon_mesh_processing.Polylines_pop_back(self)

    def erase(self, *args):
        return _CGAL_Polygon_mesh_processing.Polylines_erase(self, *args)

    def __init__(self, *args):
        _CGAL_Polygon_mesh_processing.Polylines_swiginit(self, _CGAL_Polygon_mesh_processing.new_Polylines(*args))

    def push_back(self, x):
        return _CGAL_Polygon_mesh_processing.Polylines_push_back(self, x)

    def front(self):
        return _CGAL_Polygon_mesh_processing.Polylines_front(self)

    def back(self):
        return _CGAL_Polygon_mesh_processing.Polylines_back(self)

    def assign(self, n, x):
        return _CGAL_Polygon_mesh_processing.Polylines_assign(self, n, x)

    def resize(self, *args):
        return _CGAL_Polygon_mesh_processing.Polylines_resize(self, *args)

    def insert(self, *args):
        return _CGAL_Polygon_mesh_processing.Polylines_insert(self, *args)

    def reserve(self, n):
        return _CGAL_Polygon_mesh_processing.Polylines_reserve(self, n)

    def capacity(self):
        return _CGAL_Polygon_mesh_processing.Polylines_capacity(self)
    __swig_destroy__ = _CGAL_Polygon_mesh_processing.delete_Polylines

# Register Polylines in _CGAL_Polygon_mesh_processing:
_CGAL_Polygon_mesh_processing.Polylines_swigregister(Polylines)

CGAL_VERSION_NR = _CGAL_Polygon_mesh_processing.CGAL_VERSION_NR
CGAL_SVN_REVISION = _CGAL_Polygon_mesh_processing.CGAL_SVN_REVISION
CGAL_RELEASE_DATE = _CGAL_Polygon_mesh_processing.CGAL_RELEASE_DATE

def fair(*args):
    return _CGAL_Polygon_mesh_processing.fair(*args)

def refine(*args):
    return _CGAL_Polygon_mesh_processing.refine(*args)

def triangulate_face(face, P):
    return _CGAL_Polygon_mesh_processing.triangulate_face(face, P)

def triangulate_faces(*args):
    return _CGAL_Polygon_mesh_processing.triangulate_faces(*args)

def isotropic_remeshing(*args):
    return _CGAL_Polygon_mesh_processing.isotropic_remeshing(*args)

def split_long_edges(halfedge_range, max_length, P):
    return _CGAL_Polygon_mesh_processing.split_long_edges(halfedge_range, max_length, P)

def triangulate_hole(P, h, output):
    return _CGAL_Polygon_mesh_processing.triangulate_hole(P, h, output)

def triangulate_and_refine_hole(*args):
    return _CGAL_Polygon_mesh_processing.triangulate_and_refine_hole(*args)

def triangulate_refine_and_fair_hole(*args):
    return _CGAL_Polygon_mesh_processing.triangulate_refine_and_fair_hole(*args)

def triangulate_hole_polyline(*args):
    return _CGAL_Polygon_mesh_processing.triangulate_hole_polyline(*args)

def does_self_intersect(P):
    return _CGAL_Polygon_mesh_processing.does_self_intersect(P)

def self_intersections(P, out):
    return _CGAL_Polygon_mesh_processing.self_intersections(P, out)

def is_outward_oriented(P):
    return _CGAL_Polygon_mesh_processing.is_outward_oriented(P)

def reverse_face_orientations(*args):
    return _CGAL_Polygon_mesh_processing.reverse_face_orientations(*args)

def orient_polygon_soup(points, polygons):
    return _CGAL_Polygon_mesh_processing.orient_polygon_soup(points, polygons)

def stitch_borders(*args):
    return _CGAL_Polygon_mesh_processing.stitch_borders(*args)

def polygon_soup_to_polygon_mesh(points, polygons, P):
    return _CGAL_Polygon_mesh_processing.polygon_soup_to_polygon_mesh(points, polygons, P)

def remove_isolated_vertices(P):
    return _CGAL_Polygon_mesh_processing.remove_isolated_vertices(P)

def compute_face_normal(*args):
    return _CGAL_Polygon_mesh_processing.compute_face_normal(*args)

def compute_face_normals(P, out):
    return _CGAL_Polygon_mesh_processing.compute_face_normals(P, out)

def compute_vertex_normal(*args):
    return _CGAL_Polygon_mesh_processing.compute_vertex_normal(*args)

def compute_vertex_normals(P, out):
    return _CGAL_Polygon_mesh_processing.compute_vertex_normals(P, out)

def connected_component(seed_face, P, out):
    return _CGAL_Polygon_mesh_processing.connected_component(seed_face, P, out)

def connected_components(P):
    return _CGAL_Polygon_mesh_processing.connected_components(P)

def keep_large_connected_components(P, threshold_components_to_keep):
    return _CGAL_Polygon_mesh_processing.keep_large_connected_components(P, threshold_components_to_keep)

def keep_largest_connected_components(P, nb_components_to_keep):
    return _CGAL_Polygon_mesh_processing.keep_largest_connected_components(P, nb_components_to_keep)

def keep_connected_components(*args):
    return _CGAL_Polygon_mesh_processing.keep_connected_components(*args)

def remove_connected_components(*args):
    return _CGAL_Polygon_mesh_processing.remove_connected_components(*args)

def face_area(face, P):
    return _CGAL_Polygon_mesh_processing.face_area(face, P)

def area(*args):
    return _CGAL_Polygon_mesh_processing.area(*args)

def volume(P):
    return _CGAL_Polygon_mesh_processing.volume(P)

def edge_length(hedge, P):
    return _CGAL_Polygon_mesh_processing.edge_length(hedge, P)

def face_border_length(hedge, P):
    return _CGAL_Polygon_mesh_processing.face_border_length(hedge, P)

def bbox(P):
    return _CGAL_Polygon_mesh_processing.bbox(P)

def border_halfedges(facet_range, P, out):
    return _CGAL_Polygon_mesh_processing.border_halfedges(facet_range, P, out)





print("import: 'CGAL'")
import CGAL

print("import: 'CGAL.CGAL_Kernel'")
import CGAL.CGAL_Kernel

print("import: 'CGAL.CGAL_Triangulation_2'")
import CGAL.CGAL_Triangulation_2

print("import: 'CGAL.CGAL_AABB_tree'")
import CGAL.CGAL_AABB_tree




# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""SWIG wrapper for the CGAL 2D and Surface Function Interpolation package provided under the GPL-3.0+ license"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _CGAL_Interpolation
else:
    import _CGAL_Interpolation

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import CGAL.CGAL_Triangulation_2
import CGAL.CGAL_Kernel
import CGAL.CGAL_Triangulation_3
class Double_and_bool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Interpolation.Double_and_bool_swiginit(self, _CGAL_Interpolation.new_Double_and_bool(*args))
    first = property(_CGAL_Interpolation.Double_and_bool_first_get, _CGAL_Interpolation.Double_and_bool_first_set)
    second = property(_CGAL_Interpolation.Double_and_bool_second_get, _CGAL_Interpolation.Double_and_bool_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_Interpolation.delete_Double_and_bool

# Register Double_and_bool in _CGAL_Interpolation:
_CGAL_Interpolation.Double_and_bool_swigregister(Double_and_bool)

class Double_bool_bool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    first = property(_CGAL_Interpolation.Double_bool_bool_first_get, _CGAL_Interpolation.Double_bool_bool_first_set)
    second = property(_CGAL_Interpolation.Double_bool_bool_second_get, _CGAL_Interpolation.Double_bool_bool_second_set)
    third = property(_CGAL_Interpolation.Double_bool_bool_third_get, _CGAL_Interpolation.Double_bool_bool_third_set)

    def __init__(self, *args):
        _CGAL_Interpolation.Double_bool_bool_swiginit(self, _CGAL_Interpolation.new_Double_bool_bool(*args))

    def deepcopy(self, *args):
        return _CGAL_Interpolation.Double_bool_bool_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Interpolation.delete_Double_bool_bool

# Register Double_bool_bool in _CGAL_Interpolation:
_CGAL_Interpolation.Double_bool_bool_swigregister(Double_bool_bool)

class Point_2_and_double(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Interpolation.Point_2_and_double_swiginit(self, _CGAL_Interpolation.new_Point_2_and_double(*args))
    first = property(_CGAL_Interpolation.Point_2_and_double_first_get, _CGAL_Interpolation.Point_2_and_double_first_set)
    second = property(_CGAL_Interpolation.Point_2_and_double_second_get, _CGAL_Interpolation.Point_2_and_double_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_Interpolation.delete_Point_2_and_double

# Register Point_2_and_double in _CGAL_Interpolation:
_CGAL_Interpolation.Point_2_and_double_swigregister(Point_2_and_double)

class Weighted_point_2_and_double(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Interpolation.Weighted_point_2_and_double_swiginit(self, _CGAL_Interpolation.new_Weighted_point_2_and_double(*args))
    first = property(_CGAL_Interpolation.Weighted_point_2_and_double_first_get, _CGAL_Interpolation.Weighted_point_2_and_double_first_set)
    second = property(_CGAL_Interpolation.Weighted_point_2_and_double_second_get, _CGAL_Interpolation.Weighted_point_2_and_double_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_Interpolation.delete_Weighted_point_2_and_double

# Register Weighted_point_2_and_double in _CGAL_Interpolation:
_CGAL_Interpolation.Weighted_point_2_and_double_swigregister(Weighted_point_2_and_double)

class Point_3_and_double(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Interpolation.Point_3_and_double_swiginit(self, _CGAL_Interpolation.new_Point_3_and_double(*args))
    first = property(_CGAL_Interpolation.Point_3_and_double_first_get, _CGAL_Interpolation.Point_3_and_double_first_set)
    second = property(_CGAL_Interpolation.Point_3_and_double_second_get, _CGAL_Interpolation.Point_3_and_double_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_Interpolation.delete_Point_3_and_double

# Register Point_3_and_double in _CGAL_Interpolation:
_CGAL_Interpolation.Point_3_and_double_swigregister(Point_3_and_double)

class Data_access_double_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Interpolation.Data_access_double_2_swiginit(self, _CGAL_Interpolation.new_Data_access_double_2())

    def set(self, p, value):
        return _CGAL_Interpolation.Data_access_double_2_set(self, p, value)

    def get(self, p):
        return _CGAL_Interpolation.Data_access_double_2_get(self, p)
    __swig_destroy__ = _CGAL_Interpolation.delete_Data_access_double_2

# Register Data_access_double_2 in _CGAL_Interpolation:
_CGAL_Interpolation.Data_access_double_2_swigregister(Data_access_double_2)

class Data_access_vector_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Interpolation.Data_access_vector_2_swiginit(self, _CGAL_Interpolation.new_Data_access_vector_2())

    def set(self, p, value):
        return _CGAL_Interpolation.Data_access_vector_2_set(self, p, value)

    def get(self, p):
        return _CGAL_Interpolation.Data_access_vector_2_get(self, p)
    __swig_destroy__ = _CGAL_Interpolation.delete_Data_access_vector_2

# Register Data_access_vector_2 in _CGAL_Interpolation:
_CGAL_Interpolation.Data_access_vector_2_swigregister(Data_access_vector_2)


def natural_neighbor_coordinates_2(*args):
    return _CGAL_Interpolation.natural_neighbor_coordinates_2(*args)

def regular_neighbor_coordinates_2(*args):
    return _CGAL_Interpolation.regular_neighbor_coordinates_2(*args)

def surface_neighbors_certified_3(*args):
    return _CGAL_Interpolation.surface_neighbors_certified_3(*args)

def surface_neighbors_3(*args):
    return _CGAL_Interpolation.surface_neighbors_3(*args)

def surface_neighbor_coordinates_certified_3(*args):
    return _CGAL_Interpolation.surface_neighbor_coordinates_certified_3(*args)

def surface_neighbor_coordinates_3(*args):
    return _CGAL_Interpolation.surface_neighbor_coordinates_3(*args)

def linear_interpolation(range, norm, function_values):
    return _CGAL_Interpolation.linear_interpolation(range, norm, function_values)

def quadratic_interpolation(range, norm, p, function_values, gradients):
    return _CGAL_Interpolation.quadratic_interpolation(range, norm, p, function_values, gradients)

def sibson_c1_interpolation(range, norm, p, function_values, gradients):
    return _CGAL_Interpolation.sibson_c1_interpolation(range, norm, p, function_values, gradients)

def sibson_c1_interpolation_square(range, norm, p, function_values, gradients):
    return _CGAL_Interpolation.sibson_c1_interpolation_square(range, norm, p, function_values, gradients)

def farin_c1_interpolation(range, norm, p, function_values, gradients):
    return _CGAL_Interpolation.farin_c1_interpolation(range, norm, p, function_values, gradients)

def sibson_gradient_fitting(range, norm, p, function_values):
    return _CGAL_Interpolation.sibson_gradient_fitting(range, norm, p, function_values)

def sibson_gradient_fitting_nn_2(dt, gradients, function_values):
    return _CGAL_Interpolation.sibson_gradient_fitting_nn_2(dt, gradients, function_values)





# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""SWIG wrapper for the CGAL 3D Point Set package provided under the GPL-3.0+ license"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _CGAL_Point_set_3
else:
    import _CGAL_Point_set_3

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import CGAL.CGAL_Kernel
class Point_set_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Point_set_3.Point_set_3_swiginit(self, _CGAL_Point_set_3.new_Point_set_3(*args))

    def is_empty(self):
        return _CGAL_Point_set_3.Point_set_3_is_empty(self)

    def empty(self):
        return _CGAL_Point_set_3.Point_set_3_empty(self)

    def number_of_points(self):
        return _CGAL_Point_set_3.Point_set_3_number_of_points(self)

    def size(self):
        return _CGAL_Point_set_3.Point_set_3_size(self)

    def join(self, other):
        return _CGAL_Point_set_3.Point_set_3_join(self, other)

    def clear(self):
        return _CGAL_Point_set_3.Point_set_3_clear(self)

    def clear_properties(self):
        return _CGAL_Point_set_3.Point_set_3_clear_properties(self)

    def reserve(self, c):
        return _CGAL_Point_set_3.Point_set_3_reserve(self, c)

    def resize(self, c):
        return _CGAL_Point_set_3.Point_set_3_resize(self, c)

    def insert(self, *args):
        return _CGAL_Point_set_3.Point_set_3_insert(self, *args)

    def insert_range(self, range):
        return _CGAL_Point_set_3.Point_set_3_insert_range(self, range)

    def indices(self):
        return _CGAL_Point_set_3.Point_set_3_indices(self)

    def point(self, c):
        return _CGAL_Point_set_3.Point_set_3_point(self, c)

    def normal(self, c):
        return _CGAL_Point_set_3.Point_set_3_normal(self, c)

    def remove(self, c):
        return _CGAL_Point_set_3.Point_set_3_remove(self, c)

    def is_removed(self, c):
        return _CGAL_Point_set_3.Point_set_3_is_removed(self, c)

    def garbage(self):
        return _CGAL_Point_set_3.Point_set_3_garbage(self)

    def number_of_removed_points(self):
        return _CGAL_Point_set_3.Point_set_3_number_of_removed_points(self)

    def garbage_size(self):
        return _CGAL_Point_set_3.Point_set_3_garbage_size(self)

    def has_garbage(self):
        return _CGAL_Point_set_3.Point_set_3_has_garbage(self)

    def collect_garbage(self):
        return _CGAL_Point_set_3.Point_set_3_collect_garbage(self)

    def cancel_removals(self):
        return _CGAL_Point_set_3.Point_set_3_cancel_removals(self)

    def has_int_map(self, name):
        return _CGAL_Point_set_3.Point_set_3_has_int_map(self, name)

    def add_int_map(self, name, default_value=0):
        return _CGAL_Point_set_3.Point_set_3_add_int_map(self, name, default_value)

    def int_map(self, name):
        return _CGAL_Point_set_3.Point_set_3_int_map(self, name)

    def remove_int_map(self, map):
        return _CGAL_Point_set_3.Point_set_3_remove_int_map(self, map)

    def has_float_map(self, name):
        return _CGAL_Point_set_3.Point_set_3_has_float_map(self, name)

    def add_float_map(self, name, default_value=0.0):
        return _CGAL_Point_set_3.Point_set_3_add_float_map(self, name, default_value)

    def float_map(self, name):
        return _CGAL_Point_set_3.Point_set_3_float_map(self, name)

    def remove_float_map(self, map):
        return _CGAL_Point_set_3.Point_set_3_remove_float_map(self, map)

    def has_normal_map(self):
        return _CGAL_Point_set_3.Point_set_3_has_normal_map(self)

    def add_normal_map(self):
        return _CGAL_Point_set_3.Point_set_3_add_normal_map(self)

    def normal_map(self):
        return _CGAL_Point_set_3.Point_set_3_normal_map(self)

    def remove_normal_map(self):
        return _CGAL_Point_set_3.Point_set_3_remove_normal_map(self)

    def point_map(self):
        return _CGAL_Point_set_3.Point_set_3_point_map(self)

    def copy_properties(self, other):
        return _CGAL_Point_set_3.Point_set_3_copy_properties(self, other)

    def properties(self):
        return _CGAL_Point_set_3.Point_set_3_properties(self)

    def info(self):
        return _CGAL_Point_set_3.Point_set_3_info(self)

    def range(self, *args):
        return _CGAL_Point_set_3.Point_set_3_range(self, *args)

    def points(self):
        return _CGAL_Point_set_3.Point_set_3_points(self)

    def normals(self):
        return _CGAL_Point_set_3.Point_set_3_normals(self)

    def read(self, file):
        return _CGAL_Point_set_3.Point_set_3_read(self, file)

    def write(self, file):
        return _CGAL_Point_set_3.Point_set_3_write(self, file)
    __swig_destroy__ = _CGAL_Point_set_3.delete_Point_set_3

# Register Point_set_3 in _CGAL_Point_set_3:
_CGAL_Point_set_3.Point_set_3_swigregister(Point_set_3)

class Point_set_3_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Point_set_3.Point_set_3_iterator_swiginit(self, _CGAL_Point_set_3.new_Point_set_3_iterator())

    def __iter__(self):
        return _CGAL_Point_set_3.Point_set_3_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Point_set_3.Point_set_3_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Point_set_3.Point_set_3_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Point_set_3.Point_set_3_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Point_set_3.Point_set_3_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Point_set_3.Point_set_3_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Point_set_3.Point_set_3_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Point_set_3.delete_Point_set_3_iterator

# Register Point_set_3_iterator in _CGAL_Point_set_3:
_CGAL_Point_set_3.Point_set_3_iterator_swigregister(Point_set_3_iterator)

class Point_set_3_Point_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Point_set_3.Point_set_3_Point_iterator_swiginit(self, _CGAL_Point_set_3.new_Point_set_3_Point_iterator())

    def __iter__(self):
        return _CGAL_Point_set_3.Point_set_3_Point_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Point_set_3.Point_set_3_Point_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Point_set_3.Point_set_3_Point_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Point_set_3.Point_set_3_Point_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Point_set_3.Point_set_3_Point_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Point_set_3.Point_set_3_Point_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Point_set_3.Point_set_3_Point_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Point_set_3.delete_Point_set_3_Point_iterator

# Register Point_set_3_Point_iterator in _CGAL_Point_set_3:
_CGAL_Point_set_3.Point_set_3_Point_iterator_swigregister(Point_set_3_Point_iterator)

class Point_set_3_Vector_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Point_set_3.Point_set_3_Vector_iterator_swiginit(self, _CGAL_Point_set_3.new_Point_set_3_Vector_iterator())

    def __iter__(self):
        return _CGAL_Point_set_3.Point_set_3_Vector_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Point_set_3.Point_set_3_Vector_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Point_set_3.Point_set_3_Vector_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Point_set_3.Point_set_3_Vector_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Point_set_3.Point_set_3_Vector_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Point_set_3.Point_set_3_Vector_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Point_set_3.Point_set_3_Vector_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Point_set_3.delete_Point_set_3_Vector_iterator

# Register Point_set_3_Vector_iterator in _CGAL_Point_set_3:
_CGAL_Point_set_3.Point_set_3_Vector_iterator_swigregister(Point_set_3_Vector_iterator)

class Point_set_3_Int_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Point_set_3.Point_set_3_Int_iterator_swiginit(self, _CGAL_Point_set_3.new_Point_set_3_Int_iterator())

    def __iter__(self):
        return _CGAL_Point_set_3.Point_set_3_Int_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Point_set_3.Point_set_3_Int_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Point_set_3.Point_set_3_Int_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Point_set_3.Point_set_3_Int_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Point_set_3.Point_set_3_Int_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Point_set_3.Point_set_3_Int_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Point_set_3.Point_set_3_Int_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Point_set_3.delete_Point_set_3_Int_iterator

# Register Point_set_3_Int_iterator in _CGAL_Point_set_3:
_CGAL_Point_set_3.Point_set_3_Int_iterator_swigregister(Point_set_3_Int_iterator)

class Point_set_3_Float_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Point_set_3.Point_set_3_Float_iterator_swiginit(self, _CGAL_Point_set_3.new_Point_set_3_Float_iterator())

    def __iter__(self):
        return _CGAL_Point_set_3.Point_set_3_Float_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Point_set_3.Point_set_3_Float_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Point_set_3.Point_set_3_Float_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Point_set_3.Point_set_3_Float_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Point_set_3.Point_set_3_Float_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Point_set_3.Point_set_3_Float_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Point_set_3.Point_set_3_Float_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Point_set_3.delete_Point_set_3_Float_iterator

# Register Point_set_3_Float_iterator in _CGAL_Point_set_3:
_CGAL_Point_set_3.Point_set_3_Float_iterator_swigregister(Point_set_3_Float_iterator)

class Point_set_3_Point_map(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Point_set_3.Point_set_3_Point_map_swiginit(self, _CGAL_Point_set_3.new_Point_set_3_Point_map())

    def get(self, idx):
        return _CGAL_Point_set_3.Point_set_3_Point_map_get(self, idx)

    def set(self, idx, t):
        return _CGAL_Point_set_3.Point_set_3_Point_map_set(self, idx, t)

    def is_valid(self):
        return _CGAL_Point_set_3.Point_set_3_Point_map_is_valid(self)

    def deepcopy(self, *args):
        return _CGAL_Point_set_3.Point_set_3_Point_map_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Point_set_3.delete_Point_set_3_Point_map

# Register Point_set_3_Point_map in _CGAL_Point_set_3:
_CGAL_Point_set_3.Point_set_3_Point_map_swigregister(Point_set_3_Point_map)

class Point_set_3_Vector_map(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Point_set_3.Point_set_3_Vector_map_swiginit(self, _CGAL_Point_set_3.new_Point_set_3_Vector_map())

    def get(self, idx):
        return _CGAL_Point_set_3.Point_set_3_Vector_map_get(self, idx)

    def set(self, idx, t):
        return _CGAL_Point_set_3.Point_set_3_Vector_map_set(self, idx, t)

    def is_valid(self):
        return _CGAL_Point_set_3.Point_set_3_Vector_map_is_valid(self)

    def deepcopy(self, *args):
        return _CGAL_Point_set_3.Point_set_3_Vector_map_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Point_set_3.delete_Point_set_3_Vector_map

# Register Point_set_3_Vector_map in _CGAL_Point_set_3:
_CGAL_Point_set_3.Point_set_3_Vector_map_swigregister(Point_set_3_Vector_map)

class Point_set_3_Int_map(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Point_set_3.Point_set_3_Int_map_swiginit(self, _CGAL_Point_set_3.new_Point_set_3_Int_map())

    def get(self, idx):
        return _CGAL_Point_set_3.Point_set_3_Int_map_get(self, idx)

    def set(self, idx, t):
        return _CGAL_Point_set_3.Point_set_3_Int_map_set(self, idx, t)

    def is_valid(self):
        return _CGAL_Point_set_3.Point_set_3_Int_map_is_valid(self)

    def deepcopy(self, *args):
        return _CGAL_Point_set_3.Point_set_3_Int_map_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Point_set_3.delete_Point_set_3_Int_map

# Register Point_set_3_Int_map in _CGAL_Point_set_3:
_CGAL_Point_set_3.Point_set_3_Int_map_swigregister(Point_set_3_Int_map)

class Point_set_3_Float_map(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Point_set_3.Point_set_3_Float_map_swiginit(self, _CGAL_Point_set_3.new_Point_set_3_Float_map())

    def get(self, idx):
        return _CGAL_Point_set_3.Point_set_3_Float_map_get(self, idx)

    def set(self, idx, t):
        return _CGAL_Point_set_3.Point_set_3_Float_map_set(self, idx, t)

    def is_valid(self):
        return _CGAL_Point_set_3.Point_set_3_Float_map_is_valid(self)

    def deepcopy(self, *args):
        return _CGAL_Point_set_3.Point_set_3_Float_map_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Point_set_3.delete_Point_set_3_Float_map

# Register Point_set_3_Float_map in _CGAL_Point_set_3:
_CGAL_Point_set_3.Point_set_3_Float_map_swigregister(Point_set_3_Float_map)






# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""SWIG wrapper for the CGAL 3D Point Set Processing package provided under the GPL-3.0+ license"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _CGAL_Point_set_processing_3
else:
    import _CGAL_Point_set_processing_3

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import CGAL.CGAL_Kernel
import CGAL.CGAL_Point_set_3

def bilateral_smooth_point_set(point_set, k, neighbor_radius=0., sharpness_angle=30.):
    return _CGAL_Point_set_processing_3.bilateral_smooth_point_set(point_set, k, neighbor_radius, sharpness_angle)

def compute_average_spacing(point_set, k):
    return _CGAL_Point_set_processing_3.compute_average_spacing(point_set, k)

def edge_aware_upsample_point_set(point_set, sharpness_angle=30., edge_sensitivity=1., neighbor_radius=-1., number_of_output_points=1000):
    return _CGAL_Point_set_processing_3.edge_aware_upsample_point_set(point_set, sharpness_angle, edge_sensitivity, neighbor_radius, number_of_output_points)

def estimate_global_k_neighbor_scale(point_set):
    return _CGAL_Point_set_processing_3.estimate_global_k_neighbor_scale(point_set)

def estimate_global_range_scale(point_set):
    return _CGAL_Point_set_processing_3.estimate_global_range_scale(point_set)

def grid_simplify_point_set(point_set, epsilon):
    return _CGAL_Point_set_processing_3.grid_simplify_point_set(point_set, epsilon)

def hierarchy_simplify_point_set(*args, **kwargs):
    return _CGAL_Point_set_processing_3.hierarchy_simplify_point_set(*args, **kwargs)

def jet_estimate_normals(point_set, k, neighbor_radius=0., degree_fitting=2):
    return _CGAL_Point_set_processing_3.jet_estimate_normals(point_set, k, neighbor_radius, degree_fitting)

def jet_smooth_point_set(point_set, k, neighbor_radius=0., degree_fitting=2, degree_monge=2):
    return _CGAL_Point_set_processing_3.jet_smooth_point_set(point_set, k, neighbor_radius, degree_fitting, degree_monge)

def mst_orient_normals(*args, **kwargs):
    return _CGAL_Point_set_processing_3.mst_orient_normals(*args, **kwargs)

def pca_estimate_normals(point_set, k, neighbor_radius=0.):
    return _CGAL_Point_set_processing_3.pca_estimate_normals(point_set, k, neighbor_radius)

def random_simplify_point_set(point_set, removed_percentage):
    return _CGAL_Point_set_processing_3.random_simplify_point_set(point_set, removed_percentage)

def remove_outliers(point_set, k, neighbor_radius=0., threshold_percent=10., threshold_distance=0.):
    return _CGAL_Point_set_processing_3.remove_outliers(point_set, k, neighbor_radius, threshold_percent, threshold_distance)

def vcm_estimate_normals(point_set, offset_radius, convolution_radius, k=0):
    return _CGAL_Point_set_processing_3.vcm_estimate_normals(point_set, offset_radius, convolution_radius, k)

def wlop_simplify_and_regularize_point_set(input, output, select_percentage=5., neighbor_radius=-1., number_of_iterations=35, require_uniform_sampling=False):
    return _CGAL_Point_set_processing_3.wlop_simplify_and_regularize_point_set(input, output, select_percentage, neighbor_radius, number_of_iterations, require_uniform_sampling)


